import pytest
from byu_pytest_utils import max_score, run_python, this_folder, test_files


@max_score(3)
def test_one_flashcard_incorrect():
    captured = run_python(
        this_folder / "flashcards.py",
        test_files / "one_flashcard.txt",
        stdin="That's just a conspiracy"
    )
    lines = captured.splitlines()
    assert lines[0] == "When did Christopher Columbus sail the ocean blue?"
    assert lines[1] == "Guess: Incorrect."
    assert lines[2] == 'Correct answer: In the year of 1492!'
    assert lines[3] == "You got 0/1 correct."


@max_score(3)
def test_one_flashcard_correct():
    captured = run_python(
        this_folder / "flashcards.py",
        test_files / "one_flashcard.txt",
        stdin="In the year of 1492!"
    )

    lines = captured.splitlines()
    assert lines[0] == "When did Christopher Columbus sail the ocean blue?"
    assert lines[1] == "Guess: Correct!"
    assert lines[2] == "You got 1/1 correct."


@max_score(4)
def test_four_flashcards():
    captured = run_python(
        this_folder / "flashcards.py",
        test_files / "four_flashcards.txt",
        stdin="stuff\nstuff\nidk\nstuff"
    )

    lines = captured.splitlines()
    # cards is a dictionary of known flashcards. Initialized to 0.
    cards = {'Before Mt. Everest was discovered, what was the tallest mountain in the world?': 0, "What are two things you can't eat for breakfast?": 0, 'What word becomes shorter when you add two letters to it?': 0, 'What do you call a bagel that can fly?': 0}
    # If a line is one of the flashcard prompts, add 1 to the corresponding card value.
    for line in lines:
        # Filter through lines that aren't flashcard prompts
        if line.startswith('Guess') or line.startswith('Correct') or line.startswith("You got ") or len(line) < 1:
            continue
        if line in cards:
            cards[line] += 1
        # If the flashcard is not in the card dictionary, fail the test
        else:
            pytest.fail(f'Unexpected question: {line}')
    # Since ever cards appears once, the following should all equal one
    for count in cards.values():
        assert count == 1


